module CrmBmsCms
  module Clientable
    extend ActiveSupport::Concern

    included do
      include CrmBmsCms::ClientEnum

      default_scope -> { app_scoped }
    end

    def is_active?
      locked.nil? or locked
    end
  
    def is_freeze?
      !is_active?
    end
  
    def expired?
      expires_at.present? && Time.now.to_f > expires_at.to_f
    end
  
    def industry_name
      I18n.t("enums.organization.industry")[industry.to_s.to_sym]
    end
  
    def staff_size_name
      I18n.t("enums.organization.staff_size")[staff_size.to_s.to_sym]
    end

    def to_s
      name || id.to_s
    end

    def area
      [province, city, district].map(&:to_s).uniq.join('')
    end
  
    def dingtalk_vip_trial?
      if dingding_aike_crm? && dingding_trial_account?
        account_payment? && dingding_trial_application.try(:submit_at).to_f > 15.days.ago.beginning_of_day.to_f
      else
        false
      end
    end
  
    def wx_vip_trial?
      return false if wx_free_permission?
  
      wx_aike_crm? && wx_trial_account? &&
        wx_free_permission? &&
        wx_trial_application.try(:submit_at).to_f > 15.days.ago.beginning_of_day.to_f
    end
  
    def paid?
      if AppSettings.wxwork?
        wx_paid_permission? && !expired?
      else
        account_payment? && !expired?
      end
    end
  
    def users_count
      if AppSetting.wxwork?
        wx_vip_trial? ? 10000 : super
      else
        dingtalk_vip_trial? ? 10000 : super
      end
    end

    module ClassMethods
      def app_scoped
        # 请仔细检查配置文件: config/services.yml
        if AppSettings[:app_type] == 'all' # 开发环境或测试环境应该进入这个逻辑
          all
        elsif AppSettings[:app_type] == 'dingtalk' # 钉钉独立版应该进入这个逻辑
          dingding_aike_crm
        elsif AppSettings[:app_type] == 'kingdee' # 云之家独立版应该进入这个逻辑
          kingdee_aike_crm
        elsif AppSettings[:app_type] == 'wxwork' # 企业微信应该进入这个逻辑
          wx_aike_crm
        elsif AppSettings[:app_type] == 'aliyun_dingtalk_oa' # 阿里云-钉钉(OA)-爱客版应该进入这个逻辑
          aliyun_dingding_oa_aike_crm
        elsif AppSettings[:app_type] == 'aliyun_dingtalk_one' # 阿里云-钉钉(独立套件)-爱客版应该进入这个逻辑
          aliyun_dingding_one_aike_crm
        else # 爱客正式环境应该进入这个逻辑
          normal_aike_crm
        end
      end
    end
  end
end
